@@ -110,6 +110,7 @@ MainWindow::MainWindow(QWidget *parent)
         connect(m_tabWidget, SIGNAL(mouseMiddleClick(QWidget*)), SLOT(closeTab(QWidget*)));
 
     connect(m_tabWidget, SIGNAL(mouseDoubleClick(QWidget*)), SLOT(openTabSettings(QWidget*)));
+    connect(m_tabWidget, SIGNAL(mouseDoubleClick()), SLOT(newConnectionPage()));
     connect(m_tabWidget, SIGNAL(contextMenu(QWidget*,QPoint)), SLOT(tabContextMenu(QWidget*,QPoint)));
 
     m_tabWidget->setMinimumSize(600, 400);
@@ -532,6 +533,10 @@ void MainWindow::switchFullscreen()
         hide();  // hide after showing the new window so it stays on the same screen
 
         if (m_systemTrayIcon) m_systemTrayIcon->setAssociatedWidget(m_fullscreenWindow);
+
+        actionCollection()->action("switch_fullscreen")->setIcon(KIcon("view-restore"));
+        actionCollection()->action("switch_fullscreen")->setText(i18n("Switch to Window Mode"));
+        actionCollection()->action("switch_fullscreen")->setIconText(i18n("Window Mode"));
         showRemoteViewToolbar();
     }
     if (m_tabWidget->currentWidget() == m_newConnectionWidget) {
@@ -694,7 +699,7 @@ void MainWindow::showConnectionContextMenu(const QPoint &pos)
     } else if (selectedAction == renameAction) {
         //TODO: use inline editor if possible
         bool ok = false;
-        const QString newTitle = KInputDialog::getText(i18n("Rename %1", title), i18n("Rename %1 to", title), "", &ok, this);
+        const QString newTitle = KInputDialog::getText(i18n("Rename %1", title), i18n("Rename %1 to", title), title, &ok, this);
         if (ok && !newTitle.isEmpty()) {
             BookmarkManager::updateTitle(m_bookmarkManager->getManager(), url, newTitle);
         }
@@ -785,10 +790,6 @@ void MainWindow::showRemoteViewToolbar()
     kDebug(5010);
 
     if (!m_toolBar) {
-        actionCollection()->action("switch_fullscreen")->setIcon(KIcon("view-restore"));
-        actionCollection()->action("switch_fullscreen")->setText(i18n("Switch to Window Mode"));
-        actionCollection()->action("switch_fullscreen")->setIconText(i18n("Window Mode"));
-
         m_toolBar = new FloatingToolBar(m_fullscreenWindow, m_fullscreenWindow);
         m_toolBar->winId(); // force it to be a native widget (prevents problem with QX11EmbedContainer)
         m_toolBar->setSide(FloatingToolBar::Top);
